@@ -9,7 +9,6 @@ import seaborn as sns
 
 import joblib
 
-# from absl import app, logging
 from absl import app, flags
 from logzero import logger
 
@@ -20,7 +19,10 @@ from tinybee.cos_matrix2 import cos_matrix2
 # from tinybee.gen_row_align import gen_row_align
 # from tinybee.interpolate_pset import interpolate_pset
 # from tinybee.gen_iset import gen_iset
+
 from tinybee.find_pairs import find_pairs
+from tinybee.gen_aset import gen_aset
+from tinybee.align_texts import align_texts
 
 from tinybee.embed_text import embed_text
 
@@ -29,7 +31,20 @@ flags.DEFINE_boolean("debug", False, "print debug messages.", short_name="d")
 
 
 def main(argv):
-    """Run."""
+    """Run main.
+    
+    pset1 = find_pairs(cmat)
+        cmat2tset
+        validity check based on iset
+            iset = gen_iset(cmat, verbose=verbose)
+                lowess_pairs or dbscan_pairs
+                    yhat = lowess_pairs(cmat)
+                pset = gen_row_align(yhat, src_len, tgt_len)
+                interpolate_pset
+    aset = gen_aset(pset1, src_len, tgt_len)
+    texts = align_texts(aset, src_text, tgt_text)
+    
+    """
     # logger.info(__file__)
     logger.info(argv[1:])
 
@@ -56,6 +71,7 @@ def main(argv):
     filezh = "data/hlm-ch1-zh.txt"
     hlmpara_en = Path(fileen).read_text("utf8").splitlines()
     hlmpara_zh = Path(filezh).read_text("utf8").splitlines()
+
     hlm_emb_en_file = "data/hlm_ch1_en_emb.lzma"
     hlm_emb_zh_file = "data/hlm_ch1_zh_emb.lzma"
 
@@ -63,13 +79,13 @@ def main(argv):
         hlm_emb_en = joblib.load(hlm_emb_en_file)
     else:
         hlm_emb_en = embed_text(hlmpara_en)
-        joblib.dump(hlm_emb_en, open(hlm_emb_en_file, "wb"))
+        joblib.dump(hlm_emb_en, hlm_emb_en_file, ("lzma", 3))
 
     if Path(hlm_emb_zh_file).exists():
         hlm_emb_zh = joblib.load(hlm_emb_zh_file)
     else:
         hlm_emb_zh = embed_text(hlmpara_zh)
-        joblib.dump(hlm_emb_zh, open(hlm_emb_zh_file, "wb"))
+        joblib.dump(hlm_emb_zh, hlm_emb_zh_file, ("lzma", 3))
 
     hlm_emb_en = np.array(hlm_emb_en)
     hlm_emb_zh = np.array(hlm_emb_zh)
@@ -79,14 +95,20 @@ def main(argv):
     cmat = cos_matrix2(hlm_emb_en, hlm_emb_zh)
     cmat = np.array(cmat)
 
+    # ax = sns.heatmap(cmat, cmap='gist_earth_r')
+    # ax.invert_yaxis()
+
     # cmat = joblib.load(r"data/cmat.lzma")
     # cmat = np.array(cmat)
 
     logger.info("cmat.shape: %s", cmat.shape)
 
     _ = """
+    from tinybee.cmat2tset import cmat2tset
+    
     # tset = cmat2tset(cmat)
-
+    
+    from tinybee.lowess_pairs import lowess_pairs
     yhat = lowess_pairs(cmat)
     df0 = pd.DataFrame(yhat, columns=["y00", "yargmax", "ymax"])
     fig, ax = plt.subplots()
@@ -96,10 +118,11 @@ def main(argv):
         plt.show(block=True)
 
     src_len, tgt_len = cmat.shape
+    # pset: pair set, outliers eiminated
     pset = gen_row_align(yhat, src_len, tgt_len)
     df1 = pd.DataFrame(pset, columns=["y00", "yargmax", "ymax"])
     fig, ax = plt.subplots()
-    sns.scatterplot(data=df1, x="y00", y="yargmax", size="ymax", sizes=(1, 110))
+    sns.scatterplot(data=df1, x="y00", y="yargmax", size="ymax", sizes=(1, 110), ax=ax)
 
     if "get_ipython" not in globals():
         plt.show(block=True)
@@ -111,7 +134,7 @@ def main(argv):
     iset = interpolate_pset(pset, tgt_len)
     df2 = pd.DataFrame(iset, columns=["y00", "yargmax"])
     fig, ax = plt.subplots()
-    sns.scatterplot(data=df2, x="y00", y="yargmax")
+    sns.scatterplot(data=df2, x="y00", y="yargmax", ax=ax)
 
     if "get_ipython" not in globals():
         plt.show(block=True)
@@ -135,9 +158,13 @@ def main(argv):
     # cmat = cos_matrix2(src_emb, tgt_emb)
     # cmat = np.array(cmat)
 
-    # pset = find_pairs(cmat)  # pair set with metrics
+    # directly go for pset
+    # pset1 = find_pairs(cmat)  # pair set with metrics
+    # df4 = pd.DataFrame(pset1, columns=["y00", "yargmax", "ymax"])
+    # fig, ax = plt.subplots()
+    # sns.scatterplot(data=df4, x="y00", y="yargmax", size="ymax", sizes=(1, 110), ax=ax)
 
-    # aset = gen_aset(pset, src_len, tgt_len)  # aset = find_pairs(cmat, delta)
+    # aset = gen_aset(pset1, src_len, tgt_len)
 
     # align_texts(aset, src_text, tgt_text)  # -> texts
 
